--[[
This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
]]

-- utility functions
local strsplit, floor, lower, sub = strsplit, math.floor, string.lower, string.sub
local function trim(s)
	local from = s:match"^%s*()"
	return from > #s and "" or s:match(".*%S", from)
end

-- register slash command
SLASH_BUY1 = '/buy'
function SlashCmdList.BUY(msg, editbox)
	-- parse arguments
	local name, count, too_many = strsplit(",", msg, 3)
	if too_many ~= nil then
		print("bad usage for /buy: too many arguments")
		print("example usage: /buy Starlight Rose")
		print("example usage: /buy Starlight Rose, 5")
		return
	end
	
	-- validate arguments
	name = trim(name)
	if name == "" then
		print("bad usage for /buy: need an item name")
		return
	end
	count = tonumber(count or 1)
	if count == nil or count <= 0 or count ~= floor(count) then
		print("bad usage for /buy: bad buy count")
		print("please provide a positive integer or omit the count to buy one")
		return
	end
	
	-- check if vendor is available
	local n = GetMerchantNumItems()
	if n == 0 then
		print("bad usage for /buy: must be at a vendor")
		return
	end
	
	-- find item(s)
	local search = lower(name)
	local index = 0
	for i = 1, n do
		-- if itemName is a case-insensitive, prefix-match
		if sub(lower(GetMerchantItemInfo(i)), 1, #search) == search then
			if index == 0 then
				-- first match, remember it
				index = i
			else
				-- multiple matches, quick abort
				index = -1
				break
			end
		end
	end
	
	if index >= 1 then
		-- buy the item
		--   can't buy multiple from blood vendor for some reason
		--   otherwise use GetMerchantItemMaxStack and quantity argument
		for j = 1, count do
			BuyMerchantItem(index)
		end
		return
	elseif index == 0 then
		print("error with /buy: item " .. name .. " not found")
	elseif index == -1 then
		print("error with /buy: multiple matches for " .. name)
	end
	
end
